==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/8b/8b1f431935cf2ba9a02658de4e711e2c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCampaign/Source/_index.html.twig */
class __TwigTemplate_57cd0fba8d787e95016354c9c6302844 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 7
        $context["sourceType"] = ((array_key_exists("sourceType", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 7, $this->source); })()), null)) : (null));
        // line 8
        yield "
";
        // line 9
        if (( !array_key_exists("update", $context) || Twig\Extension\CoreExtension::testEmpty((isset($context["update"]) || array_key_exists("update", $context) ? $context["update"] : (function () { throw new RuntimeError('Variable "update" does not exist.', 9, $this->source); })())))) {
            // line 10
            yield "  <div id=\"CampaignEvent_";
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape((isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 10, $this->source); })()), "html", null, true);
            yield "\" data-type=\"source\" class=\"draggable list-campaign-source list-campaign-leadsource\">
";
        }
        // line 12
        yield "<div class=\"campaign-event-content\">
    <div class=\"h5 fw-b mb-5 campaign-source-title\">";
        // line 13
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.form.lead_source"), "html", null, true);
        yield "</div>
    <div><span class=\"campaign-event-name ellipsis\"><i class=\"mr-xs campaign-event-icon ";
        // line 14
        if (("lists" == (isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 14, $this->source); })()))) {
            yield "ri-pie-chart-line";
        } else {
            yield "ri-survey-line";
        }
        yield "\"></i>";
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(((array_key_exists("names", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["names"]) || array_key_exists("names", $context) ? $context["names"] : (function () { throw new RuntimeError('Variable "names" does not exist.', 14, $this->source); })()), null)) : (null)), "html", null, true);
        yield "</span></div>
</div>

";
        // line 17
        if (( !array_key_exists("update", $context) || Twig\Extension\CoreExtension::testEmpty((isset($context["update"]) || array_key_exists("update", $context) ? $context["update"] : (function () { throw new RuntimeError('Variable "update" does not exist.', 17, $this->source); })())))) {
            // line 18
            yield "  <div class=\"campaign-event-buttons hide\">
    ";
            // line 19
            yield from             $this->loadTemplate("@MauticCore/Helper/button.html.twig", "@MauticCampaign/Source/_index.html.twig", 19)->unwrap()->yield(CoreExtension::merge($context, ["buttons" => [["href" => $this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_campaignsource_action", ["objectAction" => "edit", "objectId" =>             // line 24
(isset($context["campaignId"]) || array_key_exists("campaignId", $context) ? $context["campaignId"] : (function () { throw new RuntimeError('Variable "campaignId" does not exist.', 24, $this->source); })()), "sourceType" =>             // line 25
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 25, $this->source); })())]), "variant" => "secondary", "icon" => "ri-edit-line", "size" => "xs", "icon_only" => true, "label" => $this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.event.edit.btn.tooltip"), "attributes" => ["data-toggle" => "ajaxmodal", "data-prevent-dismiss" => "true", "data-target" => "#CampaignEventModal", "class" => "btn-edit"]], ["href" => $this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_campaignsource_action", ["objectAction" => "delete", "objectId" =>             // line 42
(isset($context["campaignId"]) || array_key_exists("campaignId", $context) ? $context["campaignId"] : (function () { throw new RuntimeError('Variable "campaignId" does not exist.', 42, $this->source); })()), "sourceType" =>             // line 43
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 43, $this->source); })())]), "variant" => "primary", "danger" => true, "icon" => "ri-close-line", "size" => "xs", "icon_only" => true, "label" => $this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.event.remove.btn.tooltip"), "attributes" => ["data-toggle" => "ajax", "data-target" => ("CampaignEvent_" .             // line 53
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 53, $this->source); })())), "data-ignore-formexit" => "true", "data-method" => "POST", "data-hide-loadingbar" => "true", "class" => "btn-delete"]]]]));
            // line 62
            yield "  </div>
</div>
";
        }
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCampaign/Source/_index.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  86 => 62,  84 => 53,  83 => 43,  82 => 42,  81 => 25,  80 => 24,  79 => 19,  76 => 18,  74 => 17,  62 => 14,  58 => 13,  55 => 12,  49 => 10,  47 => 9,  44 => 8,  42 => 7,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCampaign/Source/_index.html.twig", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Resources/views/Source/_index.html.twig");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/8b/8b1f431935cf2ba9a02658de4e711e2c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCampaign/Source/_index.html.twig */
class __TwigTemplate_57cd0fba8d787e95016354c9c6302844 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 7
        $context["sourceType"] = ((array_key_exists("sourceType", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 7, $this->source); })()), null)) : (null));
        // line 8
        yield "
";
        // line 9
        if (( !array_key_exists("update", $context) || Twig\Extension\CoreExtension::testEmpty((isset($context["update"]) || array_key_exists("update", $context) ? $context["update"] : (function () { throw new RuntimeError('Variable "update" does not exist.', 9, $this->source); })())))) {
            // line 10
            yield "  <div id=\"CampaignEvent_";
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape((isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 10, $this->source); })()), "html", null, true);
            yield "\" data-type=\"source\" class=\"draggable list-campaign-source list-campaign-leadsource\">
";
        }
        // line 12
        yield "<div class=\"campaign-event-content\">
    <div class=\"h5 fw-b mb-5 campaign-source-title\">";
        // line 13
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.form.lead_source"), "html", null, true);
        yield "</div>
    <div><span class=\"campaign-event-name ellipsis\"><i class=\"mr-xs campaign-event-icon ";
        // line 14
        if (("lists" == (isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 14, $this->source); })()))) {
            yield "ri-pie-chart-line";
        } else {
            yield "ri-survey-line";
        }
        yield "\"></i>";
        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(((array_key_exists("names", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["names"]) || array_key_exists("names", $context) ? $context["names"] : (function () { throw new RuntimeError('Variable "names" does not exist.', 14, $this->source); })()), null)) : (null)), "html", null, true);
        yield "</span></div>
</div>

";
        // line 17
        if (( !array_key_exists("update", $context) || Twig\Extension\CoreExtension::testEmpty((isset($context["update"]) || array_key_exists("update", $context) ? $context["update"] : (function () { throw new RuntimeError('Variable "update" does not exist.', 17, $this->source); })())))) {
            // line 18
            yield "  <div class=\"campaign-event-buttons hide\">
    ";
            // line 19
            yield from             $this->loadTemplate("@MauticCore/Helper/button.html.twig", "@MauticCampaign/Source/_index.html.twig", 19)->unwrap()->yield(CoreExtension::merge($context, ["buttons" => [["href" => $this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_campaignsource_action", ["objectAction" => "edit", "objectId" =>             // line 24
(isset($context["campaignId"]) || array_key_exists("campaignId", $context) ? $context["campaignId"] : (function () { throw new RuntimeError('Variable "campaignId" does not exist.', 24, $this->source); })()), "sourceType" =>             // line 25
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 25, $this->source); })())]), "variant" => "secondary", "icon" => "ri-edit-line", "size" => "xs", "icon_only" => true, "label" => $this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.event.edit.btn.tooltip"), "attributes" => ["data-toggle" => "ajaxmodal", "data-prevent-dismiss" => "true", "data-target" => "#CampaignEventModal", "class" => "btn-edit"]], ["href" => $this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_campaignsource_action", ["objectAction" => "delete", "objectId" =>             // line 42
(isset($context["campaignId"]) || array_key_exists("campaignId", $context) ? $context["campaignId"] : (function () { throw new RuntimeError('Variable "campaignId" does not exist.', 42, $this->source); })()), "sourceType" =>             // line 43
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 43, $this->source); })())]), "variant" => "primary", "danger" => true, "icon" => "ri-close-line", "size" => "xs", "icon_only" => true, "label" => $this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.campaign.event.remove.btn.tooltip"), "attributes" => ["data-toggle" => "ajax", "data-target" => ("CampaignEvent_" .             // line 53
(isset($context["sourceType"]) || array_key_exists("sourceType", $context) ? $context["sourceType"] : (function () { throw new RuntimeError('Variable "sourceType" does not exist.', 53, $this->source); })())), "data-ignore-formexit" => "true", "data-method" => "POST", "data-hide-loadingbar" => "true", "class" => "btn-delete"]]]]));
            // line 62
            yield "  </div>
</div>
";
        }
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCampaign/Source/_index.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  86 => 62,  84 => 53,  83 => 43,  82 => 42,  81 => 25,  80 => 24,  79 => 19,  76 => 18,  74 => 17,  62 => 14,  58 => 13,  55 => 12,  49 => 10,  47 => 9,  44 => 8,  42 => 7,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCampaign/Source/_index.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Resources/views/Source/_index.html.twig");
    }
}
